#include "filterlistbydialog.h"
#include "ui_filterlistbydialog.h"

FilterListByDialog::FilterListByDialog(int type, QStringList fillingList, QWidget *parent) :
    QDialog(parent),
    ui(new Ui::FilterListByDialog)
{
    ui->setupUi(this);
    this->type = type;
    ui->comboBox->addItems(fillingList);
}

FilterListByDialog::~FilterListByDialog()
{
    delete ui;
}

void FilterListByDialog::on_okButton_clicked()
{
    emit choicePicked(this->type, ui->comboBox->currentText(), ui->orderByComboBox->currentIndex());
    close();
}
